[Scummvm-cvs-logs] CVS: scummvm/scumm script_v2.cpp,2.148,2.149 scummvm.cpp,2.279,2.280

James Brown ender at users.sourceforge.net
Sun Jul 13 23:01:06 CEST 2003


Update of /cvsroot/scummvm/scummvm/scumm
In directory sc8-pr-cvs1:/tmp/cvs-serv24107/scumm

Modified Files:
	script_v2.cpp scummvm.cpp 
Log Message:
V1 Zak fixes and hacks. (Woo, it rhymes! :)


Index: scummvm.cpp
===================================================================
RCS file: /cvsroot/scummvm/scummvm/scumm/scummvm.cpp,v
retrieving revision 2.279
retrieving revision 2.280
diff -u -d -r2.279 -r2.280
--- scummvm.cpp	13 Jul 2003 20:27:28 -0000	2.279
+++ scummvm.cpp	14 Jul 2003 06:00:17 -0000	2.280
@@ -780,7 +780,7 @@
 	tempMusic = 0;
 	debug(9, "scummInit");
 
-	if (_version == 1) {
+	if ((_gameId == GID_MANIAC) && (_version == 1)) {
 		initScreens(0, 16, _screenWidth, 152);
 	} else if (_version >= 7) {
 		initScreens(0, 0, _screenWidth, _screenHeight);
@@ -2525,7 +2525,9 @@
 		_numActors = 30;
 	else if (_gameId == GID_MANIAC)
 		_numActors = 25;
-	else
+	else if ((_gameId == GID_ZAK) && (_version == 1))
+		_numActors = 14;		// FIXME: Verify this
+	else 
 		_numActors = 13;
 
 	if (_version >= 7)





More information about the Scummvm-git-logs mailing list
Index: script_v2.cpp
===================================================================
RCS file: /cvsroot/scummvm/scummvm/scumm/script_v2.cpp,v
retrieving revision 2.148
retrieving revision 2.149
diff -u -d -r2.148 -r2.149
--- script_v2.cpp	13 Jul 2003 15:13:43 -0000	2.148
+++ script_v2.cpp	14 Jul 2003 06:00:16 -0000	2.149
@@ -689,6 +689,12 @@
 			i = fetchScriptByte();
 			a->palette[i] = arg;
 			a->needRedraw = true;
+
+			// FIXME: Hack for V1 Zak
+			if ((_gameId == GID_ZAK) && (_version == 1)) {
+				fetchScriptByte();
+				fetchScriptByte();
+			}
 			break;
 
 		case 3:		// Actor Name
@@ -815,8 +821,9 @@
 		int y = fetchScriptByte() << 3;
 		slot = getVarOrDirectByte(0x80) + 1;
 		/* int unk = */ fetchScriptByte(); // ?
-		
-		if (_version == 1)	// V1 Verbs are positioned relative to the 'verb area' - under the sentence
+
+		// V1 Maniac verbs are relative to the 'verb area' - under the sentence
+		if ((_gameId == GID_MANIAC) && (_version == 1))
 			y+=9;
 
 		//printf("o2_verbOps: verb = %d, slot = %d, x = %d, y = %d, unk = %d, name = %s\n",
